.. _github-stats_3-10-3:

GitHub statistics for 3.10.3 (May 08, 2025)
===========================================

GitHub statistics for 2025/02/27 (tag: v3.10.1) - 2025/05/08

These lists are automatically generated, and may be incomplete or contain duplicates.

We closed 16 issues and merged 78 pull requests.
The full list can be seen `on GitHub <https://github.com/matplotlib/matplotlib/milestone/101?closed=1>`__

The following 28 authors contributed 128 commits.

* Alexandra Khoo
* Antony Lee
* Carlos Ramos Carreño
* David Lowry-Duda
* David Stansby
* DerWeh
* Elliott Sales de Andrade
* guillermodotn
* hannah
* Hassan Kibirige
* Ian Thomas
* James Addison
* Jody Klymak
* Kyle Sunden
* Marten H. van Kerkwijk
* Marten Henric van Kerkwijk
* martincornejo
* Mateusz Sokół
* Nicolai Weitkemper
* Oscar Gustafsson
* Praful Gulani
* prafulgulani555
* Qian Zhang
* Raphael Erik Hviding
* Ruth Comer
* Thomas A Caswell
* Tim Hoffmann
* Weh Andreas

GitHub issues and pull requests:

Pull Requests (78):

* :ghpull:`30018`: Backport PR #29907 on branch v3.10.x (Ensure text metric calculation always uses the text cache)
* :ghpull:`30010`: Backport PR #29992 on v3.10.x: Update pinned oldest win image on azure
* :ghpull:`29992`: Update pinned oldest win image on azure
* :ghpull:`29867`: Backport PR #29827 on branch v3.10.x (TST: Remove unnecessary test images)
* :ghpull:`30002`: Backport PR #29673 on branch v3.10.x (DOC: document the issues with overlaying new mpl on old mpl)
* :ghpull:`29673`: DOC: document the issues with overlaying new mpl on old mpl
* :ghpull:`29999`: Backport PR #29997 on branch v3.10.x (BLD: Ensure meson.build has the right version of Python)
* :ghpull:`29997`: BLD: Ensure meson.build has the right version of Python
* :ghpull:`29996`: Backport PR #29995 on branch v3.10.x (Fix typo: missing singlequote in unrecognized backend exception)
* :ghpull:`29995`: Fix typo: missing singlequote in unrecognized backend exception
* :ghpull:`29990`: Backport PR #29789 on branch v3.10.x (Improve layout of cheatsheets in sidebar)
* :ghpull:`29987`: Backport PR #29370 on branch v3.10.x (DOC: Improve NonUniformImage docs)
* :ghpull:`29370`: DOC: Improve NonUniformImage docs
* :ghpull:`29983`: Backport PR #29975 on branch v3.10.x (DOC: correct signature for animation update function in rain example)
* :ghpull:`29974`: Backport PR #29970 on branch v3.10.x (TST: Make refcount tests more resilient to Python changes)
* :ghpull:`29975`: DOC: correct signature for animation update function in rain example
* :ghpull:`29980`: Backport PR #29979 on branch v3.10.x (Fix typos: horizonatal -> horizontal)
* :ghpull:`29979`: Fix typos: horizonatal -> horizontal
* :ghpull:`29970`: TST: Make refcount tests more resilient to Python changes
* :ghpull:`29969`: Backport PR #29965 on branch v3.10.x (Document Axes.spines)
* :ghpull:`29965`: Document Axes.spines
* :ghpull:`29949`: Backport PR #29796 on branch v3.10.x: ci: rotate soon-to-be-unsupported GitHub Actions ubuntu-20.04 runner out of roster
* :ghpull:`29901`: Backport PR #29872 on branch v3.10.x (TST: Use placeholders for text in layout tests)
* :ghpull:`29933`: Backport PR #29931 on branch v3.10.x (Allow Python native sequences in Matplotlib ``imsave()``.)
* :ghpull:`29943`: Fix doc build on 3.10.x
* :ghpull:`29940`: Backport PR #29919 on branch v3.10.x (Handle MOVETO's, CLOSEPOLY's and empty paths in Path.interpolated)
* :ghpull:`29919`: Handle MOVETO's, CLOSEPOLY's and empty paths in Path.interpolated
* :ghpull:`29908`: TST: Use text placeholders for empty legends
* :ghpull:`29931`: Allow Python native sequences in Matplotlib ``imsave()``.
* :ghpull:`29932`: Backport PR #29920 on branch v3.10.x (Allow ``None`` in set_prop_cycle (in type hints))
* :ghpull:`29920`: Allow ``None`` in set_prop_cycle (in type hints)
* :ghpull:`29927`: Backport PR #29897 on branch v3.10.x (BUG: ensure that errorbar does not error on masked negative errors.)
* :ghpull:`29930`: Backport PR #29929 on branch v3.10.x (Correct rightparen typo)
* :ghpull:`29929`: Correct rightparen typo
* :ghpull:`29897`: BUG: ensure that errorbar does not error on masked negative errors.
* :ghpull:`29907`: Ensure text metric calculation always uses the text cache
* :ghpull:`29902`: Backport PR #29899 on branch v3.10.x ([doc] minimally document what basic units is doing)
* :ghpull:`29900`: Backport PR #29896 on branch v3.10.x (Change ``.T`` to ``.transpose()`` in ``_reshape_2D``)
* :ghpull:`29872`: TST: Use placeholders for text in layout tests
* :ghpull:`29896`: Change ``.T`` to ``.transpose()`` in ``_reshape_2D``
* :ghpull:`29888`: Backport PR #29803 on branch v3.10.x (DOC: Improve FancyArrowPatch docstring)
* :ghpull:`29880`: Backport PR #29853 on branch v3.10.x (Update lib/matplotlib/stackplot.py)
* :ghpull:`29853`: Update lib/matplotlib/stackplot.py
* :ghpull:`29868`: Backport PR #29834 on branch v3.10.x (TST: pin flake8)
* :ghpull:`29827`: TST: Remove unnecessary test images
* :ghpull:`29861`: Backport PR #29773 on branch v3.10.x (DOC: Improve interactive figures guide / Blocking input)
* :ghpull:`29859`: Backport PR #29545 on branch v3.10.x (DOC: correctly specify return type of ``figaspect``)
* :ghpull:`29545`: DOC: correctly specify return type of ``figaspect``
* :ghpull:`29858`: Backport PR #29842 on branch v3.10.x (Don't drag draggables on scroll events)
* :ghpull:`29842`: Don't drag draggables on scroll events
* :ghpull:`29848`: Backport PR #29839 on branch v3.10.x (Improve docs regarding plt.close().)
* :ghpull:`29839`: Improve docs regarding plt.close().
* :ghpull:`29818`: Backport PR #29801 on branch v3.10.x (DOC: Slightly further improve arrowstyle demo)
* :ghpull:`29814`: Backport PR #29552 on branch v3.10.x (Bug Fix: Normalize kwargs for Histogram)
* :ghpull:`29792`: Backport PR #29770 on branch v3.10.x (MNT: Move test for old ipython behavior to minver tests)
* :ghpull:`29750`: Backport PR #29748 on branch v3.10.x (Fix PyGObject version pinning in macOS tests)
* :ghpull:`29754`: Backport PR #29721 on branch v3.10.x (FIX: pyplot auto-backend detection case-sensitivity fixup)
* :ghpull:`29786`: Backport PR #29755 on branch v3.10.x (DOC: Simplify annotation arrow style reference)
* :ghpull:`29784`: Backport PR #29781 on branch v3.10.x (Fix escaping of nulls and "0" in default filenames.)
* :ghpull:`29781`: Fix escaping of nulls and "0" in default filenames.
* :ghpull:`29771`: Backport PR #29752 on branch v3.10.x (DOC: Add install instructions for pixi and uv)
* :ghpull:`29768`: Backport PR #29767 on branch v3.10.x (Add description to logit_demo.py script)
* :ghpull:`29721`: FIX: pyplot auto-backend detection case-sensitivity fixup
* :ghpull:`29737`: Backport PR #29734 on branch v3.10.x (ci: MacOS 14: temporarily upper-bound the 'PyGObject' Python package version)
* :ghpull:`29735`: Backport PR #29719 on branch v3.10.x (Fix passing singleton sequence-type styles to hist)
* :ghpull:`29719`: Fix passing singleton sequence-type styles to hist
* :ghpull:`29730`: Backport PR #29724 on branch v3.10.x (Fix SubplotSpec.get_gridspec type hint)
* :ghpull:`29724`: Fix SubplotSpec.get_gridspec type hint
* :ghpull:`29727`: Backport PR #29726 on branch v3.10.x (Add reference tag to Hatch style reference)
* :ghpull:`29709`: Backport PR #29708 on branch v3.10.x (MNT: correct version in plotting method deprecation warnings)
* :ghpull:`29708`: MNT: correct version in plotting method deprecation warnings
* :ghpull:`29692`: Backport PR #29689 on branch v3.10.x (Fix alt and caption handling in Sphinx directives)
* :ghpull:`29693`: Backport PR #29590 on branch v3.10.x (Blocked set_clim() callbacks to prevent inconsistent state (#29522))
* :ghpull:`29590`: Blocked set_clim() callbacks to prevent inconsistent state (#29522)
* :ghpull:`29689`: Fix alt and caption handling in Sphinx directives
* :ghpull:`29691`: Backport PR #29584 on branch v3.10.x (DOC: Recommend constrained_layout over tight_layout)
* :ghpull:`29584`: DOC: Recommend constrained_layout over tight_layout
* :ghpull:`29552`: Bug Fix: Normalize kwargs for Histogram

Issues (16):

* :ghissue:`29183`: [Bug]: I give an RGB image to imsave but I don't have the right color map!
* :ghissue:`29797`: [MNT]: Flaky Windows_py31x tests on Azure Pipelines
* :ghissue:`26827`: [Bug]: ImportError when using Matplotlib v3.8.0 in Python package tests
* :ghissue:`29964`: [Doc]: object description for "spines"of matplot.axes.Axes not found
* :ghissue:`29917`: [Bug]: Contour plots using mollweide-projection
* :ghissue:`29540`: [Bug]: matshow(..., fignum=...) broken
* :ghissue:`29142`: [MNT]: Draggable legend gets stuck on cursor after scroll event
* :ghissue:`29857`: [Bug]: Unexpected behavior of the line style specifiers in the histogram method
* :ghissue:`29766`: [MNT]: ci: ubuntu-20.04 GitHub Actions runner will soon be unmaintained
* :ghissue:`29812`: [MNT]: Backport request for #29552 to 3.10.x
* :ghissue:`29779`: [Bug]: get_default_filename removes '0' from file name instead of '\0' from window title
* :ghissue:`29713`: [Bug]: Matplotlib selects TkAgg backend on LXC containers
* :ghissue:`29717`: [Bug]: Using a linestyle tuple with a histogram crashes with matplotlib 3.10
* :ghissue:`29522`: [Bug]: Image color limits not correctly updated with set_clim() IFF color bar present AND new norm.vmin > old norm.vmax
* :ghissue:`17339`: Clarify that constrained_layout and tight_layout conflict with each other
* :ghissue:`28884`: [ENH]: Expand ``hist()`` signature to support aliases and plural kwargs
